@@ -1,4 +1,6 @@
 package POE::Component::SmokeBox::Recent;
+$POE::Component::SmokeBox::Recent::VERSION = '1.50';
+#ABSTRACT: A POE component to retrieve recent CPAN uploads.
 
 use strict;
 use warnings;
@@ -7,9 +9,6 @@ use POE qw(Component::SmokeBox::Recent::HTTP Component::SmokeBox::Recent::FTP Wh
 use URI;
 use HTTP::Request;
 use File::Spec;
-use vars qw($VERSION);
-
-$VERSION = '1.48';
 
 sub recent {
   my $package = shift;
@@ -238,13 +237,22 @@ sub _sig_child {
   $kernel->sig_handled();
 }
 
-1;
+qq[What's the road on the street?];
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Recent - A POE component to retrieve recent CPAN uploads.
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
   use strict;
@@ -327,16 +335,6 @@ This is generated by the poco. ARG0 will be a hash reference with the following
   'error', if something went wrong this will contain some hopefully meaningful error messages;
   'context', if you supplied a context in the constructor it will be returned here;
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl 5 itself. Please see the license that came with your Perl 5 distribution for details.
-
 =head1 KUDOS
 
 Andy Armstrong for helping me to debug accessing his CPAN mirror.
@@ -351,4 +349,15 @@ L<POE::Component::Client::HTTP>
 
 L<POE::Component::Client::FTP>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
