@@ -1,4 +1,6 @@
 package POE::Component::SmokeBox::Recent::HTTP;
+$POE::Component::SmokeBox::Recent::HTTP::VERSION = '1.50';
+#ABSTRACT: an extremely minimal HTTP client
 
 use strict;
 use warnings;
@@ -8,9 +10,6 @@ use Test::POE::Client::TCP;
 use Carp qw(carp croak);
 use HTTP::Request;
 use URI;
-use vars qw($VERSION);
-
-$VERSION = '1.48';
 
 sub spawn {
   my $package = shift;
@@ -123,7 +122,7 @@ sub _web_connected {
   my $req = HTTP::Request->new( GET => $self->{uri}->path );
   $req->protocol( 'HTTP/1.1' );
   $req->header( 'Host', $self->{address} . ( $self->{port} ne '80' ? ":$self->{port}" : '' ) );
-  $req->user_agent( sprintf( 'POE-Component-SmokeBox-Recent-HTTP/%s (perl; N; POE; en; rv:%f)', $VERSION, $VERSION ) );
+  $req->user_agent( sprintf( 'POE-Component-SmokeBox-Recent-HTTP/%s (perl; N; POE; en; rv:%f)', $POE::Component::SmokeBox::Recent::HTTP::VERSION, $POE::Component::SmokeBox::Recent::HTTP::VERSION ) );
   $self->{web}->send_to_server( $req );
   $poe_kernel->delay( '_timeout', $self->{timeout} || 60 );
   return;
@@ -178,12 +177,21 @@ sub _shutdown {
 }
 
 'Get me that file, sucker'
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::SmokeBox::Recent::HTTP - an extremely minimal HTTP client
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
   # Obtain the RECENT file from a given CPAN mirror.
@@ -279,12 +287,13 @@ response.
 
 =head1 AUTHOR
 
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+Chris Williams <chris@bingosnet.co.uk>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright E<copy> Chris Williams
+This software is copyright (c) 2017 by Chris Williams.
 
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
